@@ -2,6 +2,8 @@
 This module includes functions related to the push notification that are sent via firebase.
 """
 from django.http import JsonResponse
+from django.utils.formats import date_format
+from django.utils.timezone import localtime
 
 from ...cms.models import PushNotificationTranslation
 from ..decorators import json_response
@@ -30,6 +32,7 @@ def sent_push_notifications(request, region_slug, language_slug):
         )
         .filter(push_notification__sent_date__isnull=False)
         .filter(language__slug=language_slug)
+        .order_by("-last_updated")
     )
     if channel != "all":
         query_result = query_result.filter(push_notification__channel=channel)
@@ -51,5 +54,6 @@ def transform_notification(pnt):
         "id": str(pnt.pk),
         "title": pnt.title,
         "message": pnt.text,
-        "timestamp": pnt.push_notification.sent_date.strftime("%Y-%m-%d %H:%M:%S"),
+        "timestamp": date_format(localtime(pnt.last_updated), "Y-m-d H:i:s"),
+        "channel": pnt.push_notification.channel,
     }
