@@ -1,8 +1,11 @@
+from django.contrib.contenttypes.fields import GenericRelation
 from django.db import models
 from django.utils.functional import cached_property
 from django.utils.translation import ugettext_lazy as _
 from django.urls import reverse
 
+from linkcheck.models import Link
+
 from ..abstract_content_translation import AbstractContentTranslation
 from ..decorators import modify_fields
 
@@ -26,6 +29,7 @@ class POITranslation(AbstractContentTranslation):
     short_description = models.CharField(
         max_length=2048, verbose_name=_("short description")
     )
+    links = GenericRelation(Link, related_query_name="poi_translation")
 
     @cached_property
     def foreign_object(self):
