@@ -94,6 +94,10 @@ if BRANDING not in AVAILABLE_BRANDINGS:
         f"The branding {BRANDING!r} is not supported, must be one of {AVAILABLE_BRANDINGS}."
     )
 
+#: The default bounding box for regions with indistinct borders
+DEFAULT_BOUNDING_BOX = [[5.98865807458, 47.3024876979], [15.0169958839, 54.983104153]]
+
+
 ###############################
 # Firebase Push Notifications #
 ###############################
@@ -738,6 +742,13 @@ LINKCHECK_DISABLE_LISTENERS = bool(
     strtobool(os.environ.get("INTEGREAT_CMS_LINKCHECK_DISABLE_LISTENERS", "False"))
 )
 
+#: URL types that are not supposed to be shown in the link list (e.g. phone numbers and emails)
+LINKCHECK_IGNORED_URL_TYPES = [
+    "mailto",
+    "phone",
+    "anchor",
+]
+
 
 #############################
 # Push Notification Channel #
