@@ -22,6 +22,12 @@ API_ENDPOINTS = [
         "tests/api/expected-outputs/augsburg_de_pages.json",
         200,
     ),
+    (
+        "/api/augsburg/ar/pages/",
+        "/augsburg/ar/wp-json/extensions/v3/pages/",
+        "tests/api/expected-outputs/augsburg_ar_pages.json",
+        200,
+    ),
     (
         "/api/augsburg/de/locations/",
         "/augsburg/de/wp-json/extensions/v3/locations/",
@@ -82,6 +88,12 @@ API_ENDPOINTS = [
         "tests/api/expected-outputs/nurnberg_ar_fcm.json",
         200,
     ),
+    (
+        "/api/augsburg/de/extras/",
+        "/augsburg/de/wp-json/extensions/v3/extras/",
+        "tests/api/expected-outputs/augsburg-offers.json",
+        200,
+    ),
 ]
 
 #: This list contains the config for all API feedback views
